@@ -1,3 +1,10 @@
+use strict;
+use warnings;
+
+use vars qw($VERSION);
+
+$VERSION = 0.02;
+
 =head1 NAME
 
 Persistence::Manual::Introduction - Introduction to Persistence::Entity. 
